@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * based on the Null Theme Engine for Gtk+.
 * Copyright (c) 2008 Robert Staudinger <robert.staudinger@gmail.com>
@@ -291,7 +291,7 @@ namespace Oxygen
                 gtk_widget_show( comboBox );
 
                 // connection
-                _toolBarStyleChangedId.connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( toolBarStyleChanged ), this );
+                connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( toolBarStyleChanged ), this );
 
             }
 
@@ -335,7 +335,7 @@ namespace Oxygen
                 gtk_widget_show( comboBox );
 
                 // connection
-                _iconSizeChangedId.connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( iconSizeChanged ), this );
+                connect( G_OBJECT( comboBox ), "changed", G_CALLBACK( iconSizeChanged ), this );
 
             }
 
