@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -56,6 +56,7 @@ namespace Oxygen
         _kdeFallbackIconTheme( "gnome" ),
         _inactiveChangeSelectionColor( false ),
         _useIconEffect( true ),
+        _useBackgroundGradient( true ),
         _checkBoxStyle( CS_CHECK ),
         _tabStyle( TS_SINGLE ),
         _scrollBarAddLineButtons( 2 ),
@@ -658,15 +659,35 @@ namespace Oxygen
         std::cerr << "Oxygen::QtSettings::generateGtkColors" << std::endl;
         #endif
 
-        /*
-        TODO:
-        look at default values from GtkCssProvider for better style definitions
-        (class based, rather than widget based)
-        */
-
-        // customize gtk palette
+        // set default palette group
         _palette.setGroup( Palette::Active );
 
+        // add color definitions to css
+        _css.addColorDefinition( "theme_base_color", _palette.color( Palette::Base ) );
+        _css.addColorDefinition( "theme_bg_color", _palette.color( Palette::Window ) );
+        _css.addColorDefinition( "theme_selected_bg_color", _palette.color( Palette::Selected ) );
+
+        _css.addColorDefinition( "theme_text_color", _palette.color( Palette::Text ) );
+        _css.addColorDefinition( "theme_fg_color", _palette.color( Palette::WindowText ) );
+        _css.addColorDefinition( "theme_selected_fg_color", _palette.color( Palette::SelectedText ) );
+
+        _css.addColorDefinition( "theme_unfocused_base_color", _palette.color( Palette::Inactive, Palette::Base ) );
+        _css.addColorDefinition( "theme_unfocused_text_color", _palette.color( Palette::Inactive, Palette::Text ) );
+        _css.addColorDefinition( "theme_unfocused_fg_color", _palette.color( Palette::Inactive, Palette::WindowText ) );
+        _css.addColorDefinition( "theme_unfocused_bg_color", _palette.color( Palette::Inactive, Palette::Window ) );
+        _css.addColorDefinition( "theme_unfocused_selected_bg_color", _palette.color( Palette::Inactive, Palette::Selected ) );
+        _css.addColorDefinition( "theme_unfocused_selected_fg_color", _palette.color( Palette::Active, Palette::Text ) );
+
+        // definitions needed to get valid buttons when using Adwaita window decoration
+        _css.addColorDefinition( "button_gradient_color_a", "shade(@theme_bg_color, 1.05)" );
+        _css.addColorDefinition( "button_gradient_color_b", "@theme_bg_color" );
+        _css.addColorDefinition( "button_gradient_color_c", "shade(@theme_bg_color, 0.92)" );
+        _css.addColorDefinition( "borders", "#a7aba7" );
+
+        _css.addColorDefinition( "button_hover_gradient_color_a", "@theme_base_color" );
+        _css.addColorDefinition( "button_hover_gradient_color_b", "shade (@button_gradient_color_a, 0.94)" );
+
+        // customize widget colors
         // default text color
         _css.setCurrentSection( Gtk::CSS::defaultSection() );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Window ) ) );
@@ -694,6 +715,8 @@ namespace Oxygen
             ".info, "
             ".scale, "
             ".through, "
+            "GtkCalendar, "
+            "GtkDrawingArea, "
             "GtkExpander, "
             "GtkHandleBox, "
             "GtkImage, "
@@ -757,11 +780,19 @@ namespace Oxygen
             ".view:selected, "
             ".entry:selected, "
             "GtkEntry:selected, "
+            "GtkCalendar:selected, "
+            "GtkLabel:selected, "
             "GtkTreeView:selected, "
             "GtkTextView:selected" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Inactive, Palette::Selected ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Active, Palette::Text ) ) );
 
+        // FIXME: this is an evince bug: for content-view.view, selected is used for selected+focus.
+        // We need to adjust the colors accordingly.
+        _css.addSection( ".content-view.view:selected" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Selected ) ) );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::Active, Palette::SelectedText ) ) );
+
         // sidebars
         _css.addSection( "GtkAssistant .sidebar" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Disabled, Palette::Base ) ) );
@@ -812,6 +843,11 @@ namespace Oxygen
             _css.addToCurrentSection( color.str() );
         }
 
+        /* calendar */
+        _css.addSection( "GtkCalendar.highlight" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Inactive, Palette::Selected ) ) );
+
+
         /*
         this is stupid. Setting the color to all widgets, like above, erases the .info, warning, etc. colors.
         Need to reset them here. This is copied from gtkcssprovider.c
@@ -973,6 +1009,9 @@ namespace Oxygen
         // background pixmap
         _backgroundPixmap = _oxygen.getValue( "[Common]", "BackgroundPixmap", "" );
 
+        // background gradient
+        _useBackgroundGradient = ( _oxygen.getValue( "[Common]", "UseBackgroundGradient", "true" ) == "true" );
+
         // checkbox style
         _checkBoxStyle = (_oxygen.getValue( "[Style]", "CheckBoxStyle", "CS_CHECK" ) == "CS_CHECK") ? CS_CHECK:CS_X;
 
@@ -1168,24 +1207,20 @@ namespace Oxygen
     void QtSettings::loadExtraOptions( void )
     {
 
-        #if GTK_CHECK_VERSION( 3, 3, 0 )
-
-        // button padding
-        _css.setCurrentSection( "GtkButton" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 4px 2px" ) );
-
         // pathbar button margins
         _css.addSection( "GtkPathBar>GtkToggleButton" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_STYLE, "solid;" ) );
         _css.addToCurrentSection(
             ( gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
-            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 2px 2px 12px;" ):
-            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 12px 2px 2px;" ) );
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_WIDTH, "3px 2px 2px 12px;" ):
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_WIDTH, "3px 12px 2px 2px;" ) );
 
-        _css.addSection( "NautilusPathBar>GtkToggleButton" );
+        _css.addSection( "NautilusPathBar > GtkToggleButton" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_STYLE, "solid;" ) );
         _css.addToCurrentSection(
             ( gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
-            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "2px 2px 2px 12px;" ):
-            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "2px 12px 2px 2px;" ) );
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_WIDTH, "2px 2px 2px 12px;" ):
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_WIDTH, "2px 12px 2px 2px;" ) );
 
         // spinbox buttons
         _css.addSection( "GtkSpinButton.button" );
@@ -1194,69 +1229,6 @@ namespace Oxygen
             Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "0px 12px 0px 0px" ):
             Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "0px 0px 0px 12px" ) );
 
-        // entries
-        _css.addSection( "GtkEntry" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "4px 7px" ) );
-
-        #else
-
-        // pathbar button margins
-        _css.addSection( "GtkPathBar>GtkToggleButton" );
-        _css.addToCurrentSection( (gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
-            "  -GtkButton-inner-border: 1px 0px 0px 10px;":
-            "  -GtkButton-inner-border: 1px 10px 0px 0px;" );
-
-        // pathbar button margins
-        _css.addSection( "NautilusPathBar>GtkToggleButton" );
-        _css.addToCurrentSection( (gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
-            "  -GtkButton-inner-border: 0px 0px 0px 10px;":
-            "  -GtkButton-inner-border: 0px 10px 0px 0px;" );
-
-        // button padding
-        _css.setCurrentSection( Gtk::CSS::defaultSection() );
-        _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 2px 0px;" );
-        _css.addToCurrentSection( "  -GtkCalendar-inner-border: 0px;" );
-
-        // toggle button
-        _css.addSection( "GtkToggleButton" );
-        _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 0px 0px;" );
-
-        // entries
-        _css.addSection( "GtkEntry" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "2px 5px" ) );
-
-        #endif
-
-        #if GTK_CHECK_VERSION( 3, 7, 0 )
-
-        // menu
-        // since gtk 3.7.0, GtkMenu-horizontal-padding and vertical-padding (from gtk.css) are ignored
-        // need to use css padding and border-width instead
-        _css.addSection( "GtkMenu" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "5px 3px" ) );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BORDER_WIDTH, "0px" ) );
-
-        _css.addSection( "GtkMenu>GtkMenuItem" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "5px 4px" ) );
-
-        _css.addSection( "GtkMenu>GtkSeparatorMenuItem" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "1px 4px" ) );
-
-        #else
-
-        // menu padding
-        _css.setCurrentSection( Gtk::CSS::defaultSection() );
-        _css.addToCurrentSection( "  -GtkMenu-horizontal-padding: 3px;" );
-        _css.addToCurrentSection( "  -GtkMenu-vertical-padding: 5px;" );
-
-        _css.addSection( "GtkMenu>GtkMenuItem" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "5px 1px" ) );
-
-        _css.addSection( "GtkMenu>GtkSeparatorMenuItem" );
-        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "1px 1px" ) );
-
-        #endif
-
     }
 
     //_________________________________________________________
