@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2011 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2011 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -31,9 +31,12 @@
 
 #include <iostream>
 #include <cairo/cairo.h>
+
+#ifdef GDK_WINDOWING_X11
 #include <cairo/cairo-xlib.h>
 #include <gdk/gdkx.h>
 #include <X11/Xatom.h>
+#endif
 
 namespace Oxygen
 {
@@ -41,9 +44,13 @@ namespace Oxygen
     //______________________________________________
     ShadowHelper::ShadowHelper( void ):
         _size(0),
-        _atom(0),
         _hooksInitialized( false )
     {
+
+        #ifdef GDK_WINDOWING_X11
+        _atom = None;
+        #endif
+
         #if OXYGEN_DEBUG
         std::cerr << "Oxygen::ShadowHelper::ShadowHelper" << std::endl;
         #endif
@@ -56,9 +63,11 @@ namespace Oxygen
         std::cerr << "Oxygen::ShadowHelper::~ShadowHelper" << std::endl;
         #endif
 
+        for( WidgetMap::iterator iter = _widgets.begin(); iter != _widgets.end(); ++iter )
+        { iter->second._destroyId.disconnect(); }
+
         reset();
         _realizeHook.disconnect();
-
     }
 
     //______________________________________________
@@ -69,19 +78,27 @@ namespace Oxygen
         std::cerr << "Oxygen::ShadowHelper::reset" << std::endl;
         #endif
 
+        #ifdef GDK_WINDOWING_X11
         GdkScreen* screen = gdk_screen_get_default();
         if( !screen ) return;
 
-        Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
+        GdkDisplay *display( gdk_screen_get_display( screen ) );
+        if( display && GDK_IS_X11_DISPLAY( display )  )
+        {
+
+            // round pixmaps
+            for( PixmapList::const_iterator iter = _roundPixmaps.begin(); iter != _roundPixmaps.end(); ++iter )
+            { XFreePixmap(GDK_DISPLAY_XDISPLAY( display ), *iter); }
+
+            // square pixmaps
+            for( PixmapList::const_iterator iter = _squarePixmaps.begin(); iter != _squarePixmaps.end(); ++iter )
+            { XFreePixmap(GDK_DISPLAY_XDISPLAY( display ), *iter); }
+
+        }
+
+        #endif
 
-        // round pixmaps
-        for( PixmapList::const_iterator iter = _roundPixmaps.begin(); iter != _roundPixmaps.end(); ++iter )
-        { XFreePixmap(display, *iter); }
         _roundPixmaps.clear();
-
-        // square pixmaps
-        for( PixmapList::const_iterator iter = _squarePixmaps.begin(); iter != _squarePixmaps.end(); ++iter )
-        { XFreePixmap(display, *iter); }
         _squarePixmaps.clear();
 
         // reset size
@@ -229,6 +246,7 @@ namespace Oxygen
         #endif
 
         // create atom
+        #ifdef GDK_WINDOWING_X11
         if( !_atom )
         {
 
@@ -245,8 +263,8 @@ namespace Oxygen
             }
 
             // get display and check
-            Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
-            if( !display )
+            GdkDisplay *display( gdk_screen_get_display( screen ) );
+            if( !( display && GDK_IS_X11_DISPLAY( display ) ) )
             {
 
                 #if OXYGEN_DEBUG
@@ -256,7 +274,8 @@ namespace Oxygen
                 return;
             }
 
-           _atom = XInternAtom( display, "_KDE_NET_WM_SHADOW", False);
+           _atom = XInternAtom( GDK_DISPLAY_XDISPLAY( display ), "_KDE_NET_WM_SHADOW", False);
+
         }
 
         // make sure size is valid
@@ -311,14 +330,18 @@ namespace Oxygen
 
         }
 
+        #endif
+
     }
 
     //______________________________________________
+    #ifdef GDK_WINDOWING_X11
     Pixmap ShadowHelper::createPixmap( const Cairo::Surface& surface, int opacity ) const
     {
         assert( surface.isValid() );
-        const int width( cairo_surface_get_width( surface ) );
-        const int height( cairo_surface_get_height( surface ) );
+        int width(0);
+        int height(0);
+        cairo_surface_get_size( surface, width, height );
 
         GdkScreen* screen = gdk_screen_get_default();
         Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
@@ -350,11 +373,14 @@ namespace Oxygen
         return pixmap;
 
     }
+    #endif
 
     //______________________________________________
     void ShadowHelper::installX11Shadows( GtkWidget* widget )
     {
 
+        #ifdef GDK_WINDOWING_X11
+
         #if OXYGEN_DEBUG
         std::cerr
             << "Oxygen::ShadowHelper::installX11Shadows - "
@@ -372,6 +398,9 @@ namespace Oxygen
         GdkWindow  *window = gtk_widget_get_window( widget );
         GdkDisplay *display = gtk_widget_get_display( widget );
 
+        // do nothing if display is invalid
+        if( !GDK_IS_X11_DISPLAY( display ) ) return;
+
         std::vector<unsigned long> data;
         const bool isMenu( this->isMenu( widget ) );
 
@@ -403,6 +432,8 @@ namespace Oxygen
             GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom, XA_CARDINAL, 32, PropModeReplace,
             reinterpret_cast<const unsigned char *>(&data[0]), data.size() );
 
+        #endif
+
     }
 
     //_______________________________________________________
@@ -411,9 +442,12 @@ namespace Oxygen
 
         if( !GTK_IS_WIDGET( widget ) ) return;
 
+        #ifdef GDK_WINDOWING_X11
         GdkWindow  *window = gtk_widget_get_window( widget );
         GdkDisplay *display = gtk_widget_get_display( widget );
-        XDeleteProperty( GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom);
+        if( GDK_IS_X11_DISPLAY( display ) )
+        { XDeleteProperty( GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom); }
+        #endif
 
     }
 
