@@ -2,7 +2,7 @@
 #define oxygenstyle_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * This  library is free  software; you can  redistribute it and/or
@@ -129,11 +129,11 @@ namespace Oxygen
 
         //! fill given rectangle with flat color
         void fill( cairo_t* context, gint x, gint y, gint w, gint h, Palette::Role role ) const
-        { fill( context, x, y, w, h, settings().palette().color( Palette::Active, role ) ); }
+        { fill( context, x, y, w, h, _settings.palette().color( Palette::Active, role ) ); }
 
         //! fill given rectangle with flat color
         void fill( cairo_t* context, gint x, gint y, gint w, gint h, Palette::Group group, Palette::Role role ) const
-        { fill( context, x, y, w, h, settings().palette().color( group, role ) ); }
+        { fill( context, x, y, w, h, _settings.palette().color( group, role ) ); }
 
         //! fill given rectangle with flat color
         void fill( cairo_t*, gint, gint, gint, gint, const ColorUtils::Rgba& color ) const;
@@ -148,15 +148,21 @@ namespace Oxygen
 
         //! window background
         /*! returns true if window gradient could be rendered */
-        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), TileSet::Tiles = TileSet::Center, bool isMaximized=false );
+        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), bool isMaximized=false );
         bool renderWindowBackground( cairo_t* c, gint x, gint y, gint w, gint h, bool maximized )
-        { return renderWindowBackground( c, 0, 0, x, y, w, h, StyleOptions(), TileSet::Center, maximized );}
+        { return renderWindowBackground( c, 0, 0, x, y, w, h, StyleOptions(), maximized );}
 
-        bool renderWindowBackground( GdkWindow* window, GtkWidget* widget, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center )
-        { return renderWindowBackground( 0L, window, widget, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( GdkWindow* window, GtkWidget* widget, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions() )
+        { return renderWindowBackground( 0L, window, widget, x, y, w, h, o ); }
 
-        bool renderWindowBackground( cairo_t* context, GdkWindow* window, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center)
-        { return renderWindowBackground( context, window, 0L, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( cairo_t* context, GdkWindow* window, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions() )
+        { return renderWindowBackground( context, window, 0L, x, y, w, h, o ); }
+
+        // render background gradient
+        bool renderBackgroundGradient( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), bool isMaximized=false );
+
+        // render background pixmap
+        bool renderBackgroundPixmap( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, bool isMaximized=false );
 
         //! groupbox background
         bool renderGroupBoxBackground( cairo_t*, GtkWidget*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Center );
@@ -373,7 +379,7 @@ namespace Oxygen
         const ColorUtils::Rgba& color( Palette::Group group, Palette::Role role, const StyleOptions& option ) const
         {
             Palette::ColorSet::const_iterator iter( option._customColors.find( role ) );
-            return iter == option._customColors.end() ? settings().palette().color( group, role ) : iter->second;
+            return iter == option._customColors.end() ? _settings.palette().color( group, role ) : iter->second;
         }
 
         //! set background surface
